@@ -18,6 +18,7 @@ from peek_platform.util.LogUtil import (
     updatePeekLoggerHandlers,
     setupLoggingToSyslogServer,
 )
+from peek_platform.util.ManHoleUtil import start_manhole
 from peek_plugin_base.PeekVortexUtil import peekServerName
 from peek_logic_service import importPackages
 from peek_logic_service.storage import setupDbConn
@@ -126,6 +127,15 @@ def setupPlatform():
 
     configureCeleryApp(celeryApp, PeekPlatformConfig.config, forCaller=True)
 
+    # Setup manhole
+    if PeekPlatformConfig.config.manholeEnabled:
+        start_manhole(
+            PeekPlatformConfig.config.manholePort,
+            PeekPlatformConfig.config.manholePassword,
+            PeekPlatformConfig.config.manholePublicKeyFile,
+            PeekPlatformConfig.config.manholePrivateKeyFile,
+        )
+
 
 class HACK_AllowJsFilesUnauthed(BasicResource):
     """HACK Allow JS Files Un-Authenticated
